@@ -21,12 +21,15 @@ from sqlglot.expressions import table_ as table
 from sqlglot.expressions import union
 from sqlglot.generator import Generator
 from sqlglot.parser import Parser
+from sqlglot.schema import MappingSchema
 from sqlglot.tokens import Tokenizer, TokenType
 
-__version__ = "7.1.2"
+__version__ = "8.0.0"
 
 pretty = False
 
+schema = MappingSchema()
+
 
 def parse(sql, read=None, **opts):
     """
