@@ -108,6 +108,8 @@ class Expression(metaclass=_Expression):
 
     @property
     def alias_or_name(self):
+        if isinstance(self, Null):
+            return "NULL"
         return self.alias or self.name
 
     def __deepcopy__(self, memo):
@@ -509,7 +511,7 @@ class DerivedTable(Expression):
         return [select.alias_or_name for select in self.selects]
 
 
-class Unionable:
+class Unionable(Expression):
     def union(self, expression, distinct=True, dialect=None, **opts):
         """
         Builds a UNION expression.
@@ -659,6 +661,10 @@ class HexString(Condition):
     pass
 
 
+class ByteString(Condition):
+    pass
+
+
 class Column(Condition):
     arg_types = {"this": True, "table": False}
 
@@ -725,7 +731,7 @@ class Constraint(Expression):
 
 
 class Delete(Expression):
-    arg_types = {"with": False, "this": True, "where": False}
+    arg_types = {"with": False, "this": True, "using": False, "where": False}
 
 
 class Drop(Expression):
@@ -1105,6 +1111,14 @@ class Subqueryable(Unionable):
             return []
         return with_.expressions
 
+    @property
+    def selects(self):
+        raise NotImplementedError("Subqueryable objects must implement `selects`")
+
+    @property
+    def named_selects(self):
+        raise NotImplementedError("Subqueryable objects must implement `named_selects`")
+
     def with_(
         self,
         alias,
@@ -1192,7 +1206,7 @@ class Table(Expression):
     }
 
 
-class Union(Subqueryable, Expression):
+class Union(Subqueryable):
     arg_types = {
         "with": False,
         "this": True,
@@ -1260,7 +1274,7 @@ class Schema(Expression):
     arg_types = {"this": False, "expressions": True}
 
 
-class Select(Subqueryable, Expression):
+class Select(Subqueryable):
     arg_types = {
         "with": False,
         "expressions": False,
@@ -1315,6 +1329,7 @@ class Select(Subqueryable, Expression):
             *expressions (str or Expression): the SQL code strings to parse.
                 If a `Group` instance is passed, this is used as-is.
                 If another `Expression` instance is passed, it will be wrapped in a `Group`.
+                If nothing is passed in then a group by is not applied to the expression
             append (bool): if `True`, add to any existing expressions.
                 Otherwise, this flattens all the `Group` expression into a single expression.
             dialect (str): the dialect used to parse the input expression.
@@ -1324,6 +1339,8 @@ class Select(Subqueryable, Expression):
         Returns:
             Select: the modified expression.
         """
+        if not expressions:
+            return self if not copy else self.copy()
         return _apply_child_list_builder(
             *expressions,
             instance=self,
@@ -2562,7 +2579,7 @@ class SortArray(Func):
 
 
 class Split(Func):
-    arg_types = {"this": True, "expression": True}
+    arg_types = {"this": True, "expression": True, "limit": False}
 
 
 # Start may be omitted in the case of postgres
@@ -3204,15 +3221,22 @@ def to_identifier(alias, quoted=None):
 def to_table(sql_path, **kwargs):
     """
     Create a table expression from a `[catalog].[schema].[table]` sql path. Catalog and schema are optional.
+
+    If a table is passed in then that table is returned.
+
     Example:
         >>> to_table('catalog.db.table_name').sql()
         'catalog.db.table_name'
 
     Args:
-        sql_path(str): `[catalog].[schema].[table]` string
+        sql_path(str|Table): `[catalog].[schema].[table]` string
     Returns:
         Table: A table expression
     """
+    if sql_path is None or isinstance(sql_path, Table):
+        return sql_path
+    if not isinstance(sql_path, str):
+        raise ValueError(f"Invalid type provided for a table: {type(sql_path)}")
     table_parts = sql_path.split(".")
     catalog, db, table_name = [
         to_identifier(x) if x is not None else x for x in [None] * (3 - len(table_parts)) + table_parts
@@ -3223,7 +3247,7 @@ def to_table(sql_path, **kwargs):
 def alias_(expression, alias, table=False, dialect=None, quoted=None, **opts):
     """
     Create an Alias expression.
-    Expample:
+    Example:
         >>> alias_('foo', 'bar').sql()
         'foo AS bar'
 
